@@ -1,7 +1,6 @@
 # MIT licensed
-# Copyright (c) 2020 lilydjwg <lilydjwg@gmail.com>, et al.
+# Copyright (c) 2020-2022,2024 lilydjwg <lilydjwg@gmail.com>, et al.
 
-import atexit
 from typing import Dict, Optional, Tuple
 
 import httpx
@@ -35,7 +34,7 @@ class HttpxSession(BaseSession):
       client = httpx.AsyncClient(
         timeout = httpx.Timeout(self.timeout, pool=None),
         http2 = True,
-        proxies = {'all://': proxy},
+        proxy = proxy,
         verify = verify_cert,
       )
       self.clients[(proxy, verify_cert)] = client
@@ -50,7 +49,8 @@ class HttpxSession(BaseSession):
         method, url, json = json, content = body,
         headers = headers,
         follow_redirects = follow_redirects,
-        params = params,
+        # httpx checks for None but not ()
+        params = params or None,
       )
       err_cls: Optional[type] = None
       if r.status_code >= 500:
@@ -75,10 +75,4 @@ class HttpxSession(BaseSession):
       await client.aclose()
     del self.clients
 
-@atexit.register
-def cleanup():
-  import asyncio
-  loop = asyncio.get_event_loop()
-  loop.run_until_complete(session.aclose())
-
 session = HttpxSession()
