@@ -2,9 +2,10 @@
 # Copyright (c) 2022 Pekka Ristola <pekkarr [at] protonmail [dot] com>, et al.
 
 import pytest
-pytestmark = [pytest.mark.asyncio(scope="session"), pytest.mark.needs_net]
+pytestmark = [pytest.mark.asyncio, pytest.mark.needs_net]
 
 async def test_cran(get_version):
-    assert await get_version("xml2", {
+    ver = await get_version("xml2", {
         "source": "cran",
-    }) == "1.3.6"
+    })
+    assert ver.startswith("1.3.")
