@@ -2,7 +2,7 @@
 # Copyright (c) 2013-2020 lilydjwg <lilydjwg@gmail.com>, et al.
 
 import pytest
-pytestmark = [pytest.mark.asyncio(scope="session"),
+pytestmark = [pytest.mark.asyncio,
               pytest.mark.needs_net]
 
 @pytest.mark.flaky(reruns=10)
@@ -10,8 +10,8 @@ async def test_gitea(get_version):
     ver = await get_version("example", {
         "source": "gitea",
         "gitea": "gitea/tea"})
-    assert len(ver) == 8
-    assert ver.isdigit()
+    assert ver.startswith('20')
+    assert 'T' in ver
 
 @pytest.mark.flaky(reruns=10)
 async def test_gitea_max_tag_with_include(get_version):
